==========  ==========  ===========  ==========
Filesize    Parallel    Time         Speed
==========  ==========  ===========  ==========
512.0 KiB   1 chunk     0.37 sec.    1.4 MiB/s
512.0 KiB   1 chunk     0.45 sec.    1.1 MiB/s
512.0 KiB   1 chunk     0.29 sec.    1.7 MiB/s
512.0 KiB   1 chunk     0.34 sec.    1.5 MiB/s
512.0 KiB   1 chunk     0.31 sec.    1.6 MiB/s
512.0 KiB   1 chunk     0.32 sec.    1.6 MiB/s
512.0 KiB   1 chunk     0.30 sec.    1.6 MiB/s
512.0 KiB   1 chunk     0.31 sec.    1.6 MiB/s
512.0 KiB   1 chunk     0.35 sec.    1.4 MiB/s
512.0 KiB   1 chunk     0.31 sec.    1.6 MiB/s
512.0 KiB   2 chunks    0.22 sec.    2.3 MiB/s
512.0 KiB   2 chunks    0.22 sec.    2.3 MiB/s
512.0 KiB   2 chunks    0.22 sec.    2.3 MiB/s
512.0 KiB   2 chunks    0.21 sec.    2.4 MiB/s
512.0 KiB   2 chunks    0.28 sec.    1.8 MiB/s
512.0 KiB   2 chunks    0.20 sec.    2.5 MiB/s
512.0 KiB   2 chunks    0.22 sec.    2.3 MiB/s
512.0 KiB   2 chunks    0.34 sec.    1.5 MiB/s
512.0 KiB   2 chunks    0.21 sec.    2.4 MiB/s
512.0 KiB   2 chunks    0.21 sec.    2.3 MiB/s
512.0 KiB   3 chunks    0.21 sec.    2.4 MiB/s
512.0 KiB   3 chunks    0.20 sec.    2.6 MiB/s
512.0 KiB   3 chunks    0.21 sec.    2.4 MiB/s
512.0 KiB   3 chunks    0.21 sec.    2.4 MiB/s
512.0 KiB   3 chunks    0.19 sec.    2.7 MiB/s
512.0 KiB   3 chunks    0.23 sec.    2.2 MiB/s
512.0 KiB   3 chunks    0.26 sec.    2.0 MiB/s
512.0 KiB   3 chunks    0.20 sec.    2.5 MiB/s
512.0 KiB   3 chunks    0.20 sec.    2.5 MiB/s
512.0 KiB   3 chunks    0.21 sec.    2.3 MiB/s
512.0 KiB   4 chunks    0.17 sec.    3.0 MiB/s
512.0 KiB   4 chunks    0.14 sec.    3.5 MiB/s
512.0 KiB   4 chunks    0.16 sec.    3.1 MiB/s
512.0 KiB   4 chunks    0.14 sec.    3.6 MiB/s
512.0 KiB   4 chunks    0.16 sec.    3.1 MiB/s
512.0 KiB   4 chunks    0.17 sec.    3.0 MiB/s
512.0 KiB   4 chunks    0.17 sec.    3.0 MiB/s
512.0 KiB   4 chunks    0.15 sec.    3.4 MiB/s
512.0 KiB   4 chunks    0.17 sec.    3.0 MiB/s
512.0 KiB   4 chunks    0.15 sec.    3.4 MiB/s
512.0 KiB   5 chunks    0.16 sec.    3.1 MiB/s
512.0 KiB   5 chunks    0.15 sec.    3.3 MiB/s
512.0 KiB   5 chunks    0.14 sec.    3.7 MiB/s
512.0 KiB   5 chunks    0.14 sec.    3.5 MiB/s
512.0 KiB   5 chunks    0.15 sec.    3.2 MiB/s
512.0 KiB   5 chunks    0.15 sec.    3.3 MiB/s
512.0 KiB   5 chunks    0.13 sec.    3.7 MiB/s
512.0 KiB   5 chunks    0.14 sec.    3.6 MiB/s
512.0 KiB   5 chunks    0.14 sec.    3.6 MiB/s
512.0 KiB   5 chunks    0.17 sec.    2.9 MiB/s
512.0 KiB   6 chunks    0.16 sec.    3.0 MiB/s
512.0 KiB   6 chunks    0.14 sec.    3.5 MiB/s
512.0 KiB   6 chunks    0.14 sec.    3.5 MiB/s
512.0 KiB   6 chunks    0.16 sec.    3.2 MiB/s
512.0 KiB   6 chunks    0.16 sec.    3.1 MiB/s
512.0 KiB   6 chunks    0.14 sec.    3.5 MiB/s
512.0 KiB   6 chunks    0.16 sec.    3.2 MiB/s
512.0 KiB   6 chunks    0.16 sec.    3.1 MiB/s
512.0 KiB   6 chunks    0.13 sec.    3.7 MiB/s
512.0 KiB   6 chunks    0.20 sec.    2.6 MiB/s
512.0 KiB   7 chunks    0.15 sec.    3.4 MiB/s
512.0 KiB   7 chunks    0.14 sec.    3.6 MiB/s
512.0 KiB   7 chunks    0.14 sec.    3.5 MiB/s
512.0 KiB   7 chunks    0.20 sec.    2.4 MiB/s
512.0 KiB   7 chunks    0.17 sec.    2.9 MiB/s
512.0 KiB   7 chunks    0.17 sec.    3.0 MiB/s
512.0 KiB   7 chunks    0.19 sec.    2.6 MiB/s
512.0 KiB   7 chunks    0.16 sec.    3.1 MiB/s
512.0 KiB   7 chunks    0.18 sec.    2.8 MiB/s
512.0 KiB   7 chunks    0.17 sec.    3.0 MiB/s
512.0 KiB   8 chunks    0.28 sec.    1.8 MiB/s
512.0 KiB   8 chunks    0.14 sec.    3.6 MiB/s
512.0 KiB   8 chunks    0.19 sec.    2.6 MiB/s
512.0 KiB   8 chunks    0.17 sec.    3.0 MiB/s
512.0 KiB   8 chunks    0.17 sec.    3.0 MiB/s
512.0 KiB   8 chunks    0.15 sec.    3.3 MiB/s
512.0 KiB   8 chunks    0.14 sec.    3.5 MiB/s
512.0 KiB   8 chunks    0.15 sec.    3.3 MiB/s
512.0 KiB   8 chunks    0.17 sec.    3.0 MiB/s
512.0 KiB   8 chunks    0.14 sec.    3.5 MiB/s
512.0 KiB   9 chunks    0.14 sec.    3.5 MiB/s
512.0 KiB   9 chunks    0.14 sec.    3.5 MiB/s
512.0 KiB   9 chunks    0.15 sec.    3.4 MiB/s
512.0 KiB   9 chunks    0.14 sec.    3.6 MiB/s
512.0 KiB   9 chunks    0.15 sec.    3.4 MiB/s
512.0 KiB   9 chunks    0.16 sec.    3.2 MiB/s
512.0 KiB   9 chunks    0.14 sec.    3.6 MiB/s
512.0 KiB   9 chunks    0.14 sec.    3.5 MiB/s
512.0 KiB   9 chunks    0.14 sec.    3.6 MiB/s
512.0 KiB   9 chunks    0.15 sec.    3.4 MiB/s
512.0 KiB   10 chunks   0.15 sec.    3.3 MiB/s
512.0 KiB   10 chunks   0.16 sec.    3.1 MiB/s
512.0 KiB   10 chunks   0.17 sec.    2.9 MiB/s
512.0 KiB   10 chunks   0.15 sec.    3.4 MiB/s
512.0 KiB   10 chunks   0.15 sec.    3.3 MiB/s
512.0 KiB   10 chunks   0.17 sec.    3.0 MiB/s
512.0 KiB   10 chunks   0.17 sec.    3.0 MiB/s
512.0 KiB   10 chunks   0.17 sec.    2.9 MiB/s
512.0 KiB   10 chunks   0.15 sec.    3.3 MiB/s
512.0 KiB   10 chunks   0.15 sec.    3.4 MiB/s
20.0 MiB    1 chunk     9.00 sec.    2.2 MiB/s
20.0 MiB    1 chunk     9.55 sec.    2.1 MiB/s
20.0 MiB    1 chunk     9.26 sec.    2.2 MiB/s
20.0 MiB    1 chunk     9.87 sec.    2.0 MiB/s
20.0 MiB    1 chunk     9.52 sec.    2.1 MiB/s
20.0 MiB    1 chunk     9.43 sec.    2.1 MiB/s
20.0 MiB    1 chunk     9.56 sec.    2.1 MiB/s
20.0 MiB    1 chunk     9.67 sec.    2.1 MiB/s
20.0 MiB    1 chunk     9.67 sec.    2.1 MiB/s
20.0 MiB    1 chunk     9.83 sec.    2.0 MiB/s
20.0 MiB    2 chunks    4.75 sec.    4.2 MiB/s
20.0 MiB    2 chunks    4.96 sec.    4.0 MiB/s
20.0 MiB    2 chunks    4.77 sec.    4.2 MiB/s
20.0 MiB    2 chunks    5.30 sec.    3.8 MiB/s
20.0 MiB    2 chunks    5.05 sec.    4.0 MiB/s
20.0 MiB    2 chunks    4.62 sec.    4.3 MiB/s
20.0 MiB    2 chunks    4.92 sec.    4.1 MiB/s
20.0 MiB    2 chunks    4.75 sec.    4.2 MiB/s
20.0 MiB    2 chunks    5.08 sec.    3.9 MiB/s
20.0 MiB    2 chunks    4.97 sec.    4.0 MiB/s
20.0 MiB    3 chunks    3.10 sec.    6.4 MiB/s
20.0 MiB    3 chunks    3.17 sec.    6.3 MiB/s
20.0 MiB    3 chunks    3.53 sec.    5.7 MiB/s
20.0 MiB    3 chunks    3.17 sec.    6.3 MiB/s
20.0 MiB    3 chunks    3.26 sec.    6.1 MiB/s
20.0 MiB    3 chunks    3.10 sec.    6.5 MiB/s
20.0 MiB    3 chunks    3.24 sec.    6.2 MiB/s
20.0 MiB    3 chunks    3.41 sec.    5.9 MiB/s
20.0 MiB    3 chunks    3.36 sec.    5.9 MiB/s
20.0 MiB    3 chunks    3.45 sec.    5.8 MiB/s
20.0 MiB    4 chunks    2.47 sec.    8.1 MiB/s
20.0 MiB    4 chunks    2.74 sec.    7.3 MiB/s
20.0 MiB    4 chunks    2.43 sec.    8.2 MiB/s
20.0 MiB    4 chunks    2.61 sec.    7.7 MiB/s
20.0 MiB    4 chunks    2.42 sec.    8.3 MiB/s
20.0 MiB    4 chunks    2.73 sec.    7.3 MiB/s
20.0 MiB    4 chunks    2.37 sec.    8.4 MiB/s
20.0 MiB    4 chunks    2.42 sec.    8.3 MiB/s
20.0 MiB    4 chunks    2.39 sec.    8.4 MiB/s
20.0 MiB    4 chunks    2.52 sec.    7.9 MiB/s
20.0 MiB    5 chunks    1.96 sec.    10.2 MiB/s
20.0 MiB    5 chunks    2.02 sec.    9.9 MiB/s
20.0 MiB    5 chunks    1.98 sec.    10.1 MiB/s
20.0 MiB    5 chunks    1.98 sec.    10.1 MiB/s
20.0 MiB    5 chunks    2.07 sec.    9.7 MiB/s
20.0 MiB    5 chunks    2.33 sec.    8.6 MiB/s
20.0 MiB    5 chunks    2.21 sec.    9.1 MiB/s
20.0 MiB    5 chunks    1.97 sec.    10.2 MiB/s
20.0 MiB    5 chunks    1.92 sec.    10.4 MiB/s
20.0 MiB    5 chunks    1.92 sec.    10.4 MiB/s
20.0 MiB    6 chunks    1.95 sec.    10.3 MiB/s
20.0 MiB    6 chunks    2.11 sec.    9.5 MiB/s
20.0 MiB    6 chunks    1.88 sec.    10.6 MiB/s
20.0 MiB    6 chunks    1.72 sec.    11.6 MiB/s
20.0 MiB    6 chunks    1.67 sec.    12.0 MiB/s
20.0 MiB    6 chunks    1.65 sec.    12.1 MiB/s
20.0 MiB    6 chunks    1.73 sec.    11.6 MiB/s
20.0 MiB    6 chunks    2.04 sec.    9.8 MiB/s
20.0 MiB    6 chunks    1.69 sec.    11.8 MiB/s
20.0 MiB    6 chunks    1.70 sec.    11.8 MiB/s
20.0 MiB    7 chunks    1.47 sec.    13.6 MiB/s
20.0 MiB    7 chunks    1.53 sec.    13.1 MiB/s
20.0 MiB    7 chunks    1.65 sec.    12.1 MiB/s
20.0 MiB    7 chunks    1.56 sec.    12.9 MiB/s
20.0 MiB    7 chunks    1.71 sec.    11.7 MiB/s
20.0 MiB    7 chunks    1.51 sec.    13.3 MiB/s
20.0 MiB    7 chunks    1.48 sec.    13.5 MiB/s
20.0 MiB    7 chunks    1.45 sec.    13.8 MiB/s
20.0 MiB    7 chunks    1.52 sec.    13.2 MiB/s
20.0 MiB    7 chunks    1.57 sec.    12.7 MiB/s
20.0 MiB    8 chunks    1.60 sec.    12.5 MiB/s
20.0 MiB    8 chunks    1.49 sec.    13.4 MiB/s
20.0 MiB    8 chunks    1.26 sec.    15.9 MiB/s
20.0 MiB    8 chunks    1.37 sec.    14.6 MiB/s
20.0 MiB    8 chunks    1.30 sec.    15.4 MiB/s
20.0 MiB    8 chunks    1.27 sec.    15.7 MiB/s
20.0 MiB    8 chunks    1.36 sec.    14.7 MiB/s
20.0 MiB    8 chunks    1.35 sec.    14.8 MiB/s
20.0 MiB    8 chunks    1.72 sec.    11.7 MiB/s
20.0 MiB    8 chunks    1.54 sec.    13.0 MiB/s
20.0 MiB    9 chunks    1.22 sec.    16.4 MiB/s
20.0 MiB    9 chunks    1.36 sec.    14.7 MiB/s
20.0 MiB    9 chunks    1.22 sec.    16.4 MiB/s
20.0 MiB    9 chunks    1.32 sec.    15.2 MiB/s
20.0 MiB    9 chunks    1.25 sec.    16.0 MiB/s
20.0 MiB    9 chunks    1.21 sec.    16.5 MiB/s
20.0 MiB    9 chunks    1.61 sec.    12.4 MiB/s
20.0 MiB    9 chunks    1.20 sec.    16.7 MiB/s
20.0 MiB    9 chunks    1.20 sec.    16.7 MiB/s
20.0 MiB    9 chunks    1.18 sec.    16.9 MiB/s
20.0 MiB    10 chunks   1.21 sec.    16.6 MiB/s
20.0 MiB    10 chunks   1.16 sec.    17.3 MiB/s
20.0 MiB    10 chunks   1.23 sec.    16.3 MiB/s
20.0 MiB    10 chunks   1.11 sec.    18.0 MiB/s
20.0 MiB    10 chunks   1.10 sec.    18.1 MiB/s
20.0 MiB    10 chunks   1.08 sec.    18.5 MiB/s
20.0 MiB    10 chunks   1.78 sec.    11.3 MiB/s
20.0 MiB    10 chunks   1.15 sec.    17.4 MiB/s
20.0 MiB    10 chunks   1.32 sec.    15.2 MiB/s
20.0 MiB    10 chunks   1.29 sec.    15.5 MiB/s
200.0 MiB   1 chunk     135.76 sec.  1.5 MiB/s
200.0 MiB   1 chunk     141.38 sec.  1.4 MiB/s
200.0 MiB   1 chunk     136.80 sec.  1.5 MiB/s
200.0 MiB   1 chunk     131.92 sec.  1.5 MiB/s
200.0 MiB   1 chunk     136.55 sec.  1.5 MiB/s
200.0 MiB   2 chunks    77.56 sec.   2.6 MiB/s
200.0 MiB   2 chunks    84.90 sec.   2.4 MiB/s
200.0 MiB   2 chunks    70.32 sec.   2.8 MiB/s
200.0 MiB   2 chunks    68.49 sec.   2.9 MiB/s
200.0 MiB   2 chunks    72.29 sec.   2.8 MiB/s
200.0 MiB   3 chunks    42.73 sec.   4.7 MiB/s
200.0 MiB   3 chunks    47.09 sec.   4.2 MiB/s
200.0 MiB   3 chunks    45.67 sec.   4.4 MiB/s
200.0 MiB   3 chunks    44.97 sec.   4.4 MiB/s
200.0 MiB   3 chunks    49.74 sec.   4.0 MiB/s
200.0 MiB   4 chunks    29.57 sec.   6.8 MiB/s
200.0 MiB   4 chunks    38.33 sec.   5.2 MiB/s
200.0 MiB   4 chunks    36.20 sec.   5.5 MiB/s
200.0 MiB   4 chunks    35.22 sec.   5.7 MiB/s
200.0 MiB   4 chunks    33.46 sec.   6.0 MiB/s
200.0 MiB   5 chunks    31.15 sec.   6.4 MiB/s
200.0 MiB   5 chunks    29.93 sec.   6.7 MiB/s
200.0 MiB   5 chunks    34.07 sec.   5.9 MiB/s
200.0 MiB   5 chunks    26.57 sec.   7.5 MiB/s
200.0 MiB   5 chunks    27.01 sec.   7.4 MiB/s
200.0 MiB   6 chunks    22.69 sec.   8.8 MiB/s
200.0 MiB   6 chunks    22.59 sec.   8.9 MiB/s
200.0 MiB   6 chunks    24.96 sec.   8.0 MiB/s
200.0 MiB   6 chunks    24.67 sec.   8.1 MiB/s
200.0 MiB   6 chunks    20.87 sec.   9.6 MiB/s
200.0 MiB   7 chunks    20.57 sec.   9.7 MiB/s
200.0 MiB   7 chunks    21.57 sec.   9.3 MiB/s
200.0 MiB   7 chunks    26.18 sec.   7.6 MiB/s
200.0 MiB   7 chunks    22.10 sec.   9.1 MiB/s
200.0 MiB   7 chunks    18.90 sec.   10.6 MiB/s
200.0 MiB   8 chunks    16.07 sec.   12.4 MiB/s
200.0 MiB   8 chunks    17.91 sec.   11.2 MiB/s
200.0 MiB   8 chunks    19.04 sec.   10.5 MiB/s
200.0 MiB   8 chunks    20.05 sec.   10.0 MiB/s
200.0 MiB   8 chunks    18.35 sec.   10.9 MiB/s
200.0 MiB   9 chunks    17.29 sec.   11.6 MiB/s
200.0 MiB   9 chunks    18.34 sec.   10.9 MiB/s
200.0 MiB   9 chunks    16.01 sec.   12.5 MiB/s
200.0 MiB   9 chunks    16.85 sec.   11.9 MiB/s
200.0 MiB   9 chunks    18.84 sec.   10.6 MiB/s
200.0 MiB   10 chunks   15.50 sec.   12.9 MiB/s
200.0 MiB   10 chunks   16.52 sec.   12.1 MiB/s
200.0 MiB   10 chunks   14.89 sec.   13.4 MiB/s
200.0 MiB   10 chunks   14.17 sec.   14.1 MiB/s
200.0 MiB   10 chunks   13.72 sec.   14.6 MiB/s
2.0 GiB     1 chunk     420.82 sec.  4.9 MiB/s
2.0 GiB     1 chunk     451.54 sec.  4.5 MiB/s
2.0 GiB     1 chunk     428.31 sec.  4.8 MiB/s
2.0 GiB     1 chunk     440.59 sec.  4.6 MiB/s
2.0 GiB     1 chunk     447.76 sec.  4.6 MiB/s
2.0 GiB     2 chunks    226.30 sec.  9.0 MiB/s
2.0 GiB     2 chunks    231.35 sec.  8.9 MiB/s
2.0 GiB     2 chunks    225.71 sec.  9.1 MiB/s
2.0 GiB     2 chunks    220.77 sec.  9.3 MiB/s
2.0 GiB     2 chunks    212.98 sec.  9.6 MiB/s
2.0 GiB     3 chunks    166.37 sec.  12.3 MiB/s
2.0 GiB     3 chunks    160.61 sec.  12.8 MiB/s
2.0 GiB     3 chunks    147.93 sec.  13.8 MiB/s
2.0 GiB     3 chunks    149.86 sec.  13.7 MiB/s
2.0 GiB     3 chunks    156.64 sec.  13.1 MiB/s
2.0 GiB     4 chunks    116.35 sec.  17.6 MiB/s
2.0 GiB     4 chunks    114.33 sec.  17.9 MiB/s
2.0 GiB     4 chunks    115.49 sec.  17.7 MiB/s
2.0 GiB     4 chunks    124.13 sec.  16.5 MiB/s
2.0 GiB     4 chunks    112.07 sec.  18.3 MiB/s
2.0 GiB     5 chunks    93.83 sec.   21.8 MiB/s
2.0 GiB     5 chunks    95.32 sec.   21.5 MiB/s
2.0 GiB     5 chunks    89.49 sec.   22.9 MiB/s
2.0 GiB     5 chunks    92.30 sec.   22.2 MiB/s
2.0 GiB     5 chunks    87.51 sec.   23.4 MiB/s
2.0 GiB     6 chunks    73.43 sec.   27.9 MiB/s
2.0 GiB     6 chunks    77.02 sec.   26.6 MiB/s
2.0 GiB     6 chunks    72.52 sec.   28.2 MiB/s
2.0 GiB     6 chunks    82.02 sec.   25.0 MiB/s
2.0 GiB     6 chunks    74.44 sec.   27.5 MiB/s
2.0 GiB     7 chunks    66.30 sec.   30.9 MiB/s
2.0 GiB     7 chunks    64.86 sec.   31.6 MiB/s
2.0 GiB     7 chunks    62.01 sec.   33.0 MiB/s
2.0 GiB     7 chunks    60.66 sec.   33.8 MiB/s
2.0 GiB     7 chunks    64.88 sec.   31.6 MiB/s
2.0 GiB     8 chunks    52.86 sec.   38.7 MiB/s
2.0 GiB     8 chunks    51.64 sec.   39.7 MiB/s
2.0 GiB     8 chunks    54.50 sec.   37.6 MiB/s
2.0 GiB     8 chunks    55.25 sec.   37.1 MiB/s
2.0 GiB     8 chunks    53.89 sec.   38.0 MiB/s
2.0 GiB     9 chunks    52.94 sec.   38.7 MiB/s
2.0 GiB     9 chunks    48.63 sec.   42.1 MiB/s
2.0 GiB     9 chunks    49.88 sec.   41.1 MiB/s
2.0 GiB     9 chunks    47.51 sec.   43.1 MiB/s
2.0 GiB     9 chunks    47.85 sec.   42.8 MiB/s
2.0 GiB     10 chunks   43.06 sec.   47.6 MiB/s
2.0 GiB     10 chunks   44.31 sec.   46.2 MiB/s
2.0 GiB     10 chunks   40.69 sec.   50.3 MiB/s
2.0 GiB     10 chunks   42.09 sec.   48.7 MiB/s
2.0 GiB     10 chunks   42.30 sec.   48.4 MiB/s
==========  ==========  ===========  ==========